==> Paws-0.30.tar.gz: Paws-0.30/lib/Paws/S3/ListBuckets.pm <==

package Paws::S3::ListBuckets;
  use Moose;

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'ListBuckets');
  class_has _api_uri  => (isa => 'Str', is => 'ro', default => '/');
  class_has _api_method  => (isa => 'Str', is => 'ro', default => 'GET');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::S3::ListBucketsOutput');
  class_has _result_key => (isa => 'Str', is => 'ro');
  
1;

### main pod documentation begin ###

=head1 NAME

Paws::S3::ListBuckets - Arguments for method ListBuckets on Paws::S3

=head1 DESCRIPTION

This class represents the parameters used for calling the method ListBuckets on the 
Amazon Simple Storage Service service. Use the attributes of this class
as arguments to method ListBuckets.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to ListBuckets.

As an example:

  $service_obj->ListBuckets(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES



=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method ListBuckets in L<Paws::S3>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.37.tar.gz: Paws-0.37/lib/Paws/S3/ListBuckets.pm <==

package Paws::S3::ListBuckets;
  use Moose;

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'ListBuckets');
  class_has _api_uri  => (isa => 'Str', is => 'ro', default => '/');
  class_has _api_method  => (isa => 'Str', is => 'ro', default => 'GET');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::S3::ListBucketsOutput');
  class_has _result_key => (isa => 'Str', is => 'ro');
  
1;

### main pod documentation begin ###

=head1 NAME

Paws::S3::ListBuckets - Arguments for method ListBuckets on L<Paws::S3>

=head1 DESCRIPTION

This class represents the parameters used for calling the method ListBuckets on the
L<Amazon Simple Storage Service|Paws::S3> service. Use the attributes of this class
as arguments to method ListBuckets.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to ListBuckets.

=head1 SYNOPSIS

    my $s3 = Paws->service('S3');
    my $ListBucketsOutput = $s3->ListBuckets();

    # Results:
    my $Owner   = $ListBucketsOutput->Owner;
    my $Buckets = $ListBucketsOutput->Buckets;

    # Returns a L<Paws::S3::ListBucketsOutput> object.

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/s3/ListBuckets>

=head1 ATTRIBUTES



=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method ListBuckets in L<Paws::S3>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut
